CRABpy
======

This library provides access to the CRAB and CAPAKEY webservices operated by
the AGIV. Because connecting to these SOAP services from python can be somewhat
complicated, this library makes it easier.

.. image:: https://readthedocs.org/projects/crabpy/badge/?version=latest
        :target: https://readthedocs.org/projects/crabpy/?badge=latest
.. image:: https://badge.fury.io/py/crabpy.png
        :target: http://badge.fury.io/py/crabpy

.. image:: https://travis-ci.org/OnroerendErfgoed/crabpy.png?branch=master
        :target: https://travis-ci.org/OnroerendErfgoed/crabpy
.. image:: https://coveralls.io/repos/OnroerendErfgoed/crabpy/badge.png?branch=master
        :target: https://coveralls.io/r/OnroerendErfgoed/crabpy?branch=master
.. image:: https://scrutinizer-ci.com/g/OnroerendErfgoed/crabpy/badges/quality-score.png?b=master
        :target: https://scrutinizer-ci.com/g/OnroerendErfgoed/crabpy/?branch=master
